xerotrust
=========
|Docs|_  |PyPI|_ |Git|_

.. |Docs| image:: https://readthedocs.org/projects/xerotrust/badge/?version=latest
.. _Docs: https://xerotrust.readthedocs.io/

.. |PyPI| image:: https://badge.fury.io/py/xerotrust.svg
.. _PyPI: https://pypi.org/project/xerotrust/

.. |Git| image:: https://github.com/cjw296/xerotrust/actions/workflows/ci.yml/badge.svg
.. _Git: https://github.com/cjw296/xerotrust

This package provides a command line tool to explore and export data from `Xero`__ accounts.
The intention behind this is to give a safety net in the event that you lose access to your
Xero accounting data, and also to allow you to analyse it with traditional tools such as
Excel along with novel approaches you may wish to take using LLMs.

__ https://www.xero.com/
